Achilles - Django AJAX Framework
================================

.. image:: https://pypip.in/v/django-achilles/badge.png
  :target: https://pypi.python.org/pypi/django-achilles

.. image:: https://secure.travis-ci.org/exekias/django-achilles.png?branch=master
  :target: http://travis-ci.org/exekias/django-achilles

.. image:: https://coveralls.io/repos/exekias/django-achilles/badge.png?branch=master
  :target: https://coveralls.io/r/exekias/django-achilles?branch=master

Achilles provides a framework to communicate with Django applications using
AJAX. Trough the use of some primitives it allows you to build asynchronous
applications without the need of writting javascript to manage client side.
